Class: Aws::DynamoDBStreams::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DynamoDBStreams::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-dynamodbstreams/client.rb
Overview
An API client for DynamoDBStreams. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DynamoDBStreams::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#describe_stream(params = {}) ⇒ Types::DescribeStreamOutput
Returns information about a stream, including the current status of the stream, its Amazon Resource Name (ARN), the composition of its shards, and its corresponding DynamoDB table.
-
#get_records(params = {}) ⇒ Types::GetRecordsOutput
Retrieves the stream records from a given shard.
-
#get_shard_iterator(params = {}) ⇒ Types::GetShardIteratorOutput
Returns a shard iterator.
-
#list_streams(params = {}) ⇒ Types::ListStreamsOutput
Returns an array of stream ARNs associated with the current account and endpoint.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
484 485 486 |
# File 'lib/aws-sdk-dynamodbstreams/client.rb', line 484 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
966 967 968 |
# File 'lib/aws-sdk-dynamodbstreams/client.rb', line 966 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
969 970 971 |
# File 'lib/aws-sdk-dynamodbstreams/client.rb', line 969 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 |
# File 'lib/aws-sdk-dynamodbstreams/client.rb', line 939 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DynamoDBStreams') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-dynamodbstreams' context[:gem_version] = '1.92.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_stream(params = {}) ⇒ Types::DescribeStreamOutput
Returns information about a stream, including the current status of the stream, its Amazon Resource Name (ARN), the composition of its shards, and its corresponding DynamoDB table.
<note markdown=“1”> You can call ‘DescribeStream` at a maximum rate of 10 times per second.
</note>
Each shard in the stream has a ‘SequenceNumberRange` associated with it. If the `SequenceNumberRange` has a `StartingSequenceNumber` but no `EndingSequenceNumber`, then the shard is still open (able to receive more stream records). If both `StartingSequenceNumber` and `EndingSequenceNumber` are present, then that shard is closed and can no longer receive more data.
622 623 624 625 |
# File 'lib/aws-sdk-dynamodbstreams/client.rb', line 622 def describe_stream(params = {}, = {}) req = build_request(:describe_stream, params) req.send_request() end |
#get_records(params = {}) ⇒ Types::GetRecordsOutput
Retrieves the stream records from a given shard.
Specify a shard iterator using the ‘ShardIterator` parameter. The shard iterator specifies the position in the shard from which you want to start reading stream records sequentially. If there are no stream records available in the portion of the shard that the iterator points to, `GetRecords` returns an empty list. Note that it might take multiple calls to get to a portion of the shard that contains stream records.
<note markdown=“1”> ‘GetRecords` can retrieve a maximum of 1 MB of data or 1000 stream records, whichever comes first.
</note>
768 769 770 771 |
# File 'lib/aws-sdk-dynamodbstreams/client.rb', line 768 def get_records(params = {}, = {}) req = build_request(:get_records, params) req.send_request() end |
#get_shard_iterator(params = {}) ⇒ Types::GetShardIteratorOutput
Returns a shard iterator. A shard iterator provides information about how to retrieve the stream records from within a shard. Use the shard iterator in a subsequent ‘GetRecords` request to read the stream records from the shard.
<note markdown=“1”> A shard iterator expires 15 minutes after it is returned to the requester.
</note>
851 852 853 854 |
# File 'lib/aws-sdk-dynamodbstreams/client.rb', line 851 def get_shard_iterator(params = {}, = {}) req = build_request(:get_shard_iterator, params) req.send_request() end |
#list_streams(params = {}) ⇒ Types::ListStreamsOutput
Returns an array of stream ARNs associated with the current account and endpoint. If the ‘TableName` parameter is present, then `ListStreams` will return only the streams ARNs for that table.
<note markdown=“1”> You can call ‘ListStreams` at a maximum rate of 5 times per second.
</note>
930 931 932 933 |
# File 'lib/aws-sdk-dynamodbstreams/client.rb', line 930 def list_streams(params = {}, = {}) req = build_request(:list_streams, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
959 960 961 |
# File 'lib/aws-sdk-dynamodbstreams/client.rb', line 959 def waiter_names [] end |